const { description } = require('../../package')

module.exports = {
  locales: {
    '/': {
      lang: 'de-DE',
      title: 'LfK! Dokumentation',
      description: 'Dokumentation für das Lauf für Kaya! Läufersystem'
    },
    '/en/': {
      lang: 'en-US',
      title: 'LfK! Documentation',
      description: 'The official documentation for the LfK! "Läufersystem"'
    }
  },
  head: [
    ['meta', { name: 'theme-color', content: '#3eaf7c' }],
    ['meta', { name: 'apple-mobile-web-app-capable', content: 'yes' }],
    ['meta', { name: 'apple-mobile-web-app-status-bar-style', content: 'black' }]
  ],
  theme: 'default-prefers-color-scheme',
  themeConfig: {
    repo: '',
    editLinks: false,
    docsDir: '',
    editLinkText: '',
    lastUpdated: false,
    locales: {
      '/': {
        selectText: 'Sprachen',
        label: 'Deutsch (German)',
        nav: [
          {
            text: 'Für Nutzer',
            link: '/users/',
          },
          {
            text: 'Für Admins',
            link: '/admins/'
          },
          {
            text: 'Über den Selfservice',
            link: '/selfservice/'
          },
          {
            text: 'Scannerstationen',
            link: '/scanstations/'
          },
          {
            text: 'Source Code',
            link: 'https://git.odit.services/lfk'
          }
        ],
        sidebar: {
          '/users/': [
            {
              title: 'Nutzerdokumentation',
              collapsable: false,
              children: [
                '',
                'accounts',
                'organizations',
                'teams',
                'runners',
                'runner_import',
                'donors',
                'donations',
                'cards',
                'sponsoring_contracts',
                'tracks',
                'scans',
                'scanstations'
              ]
            }
          ],
          '/admins/': [
            {
              title: 'Administrative Dokumentation',
              collapsable: false,
              children: [
                '',
                'quickstart',
                'installation',
                'users',
                'usergroups'
              ]
            }
          ],
          '/selfservice/': [
            {
              title: 'Selfservice Dokumentation',
              collapsable: false,
              children: [
                '',
                'org_selfservice'
              ]
            }
          ],
          '/scanstations/': [
            {
              title: 'Scannerstation Dokumentation',
              collapsable: false,
              children: [
                '',
                'install',
                'config',
                'hardware'
              ]
            }
          ],
        }
      },
      '/en/': {
        selectText: 'Languages',
        label: 'English',
        nav: [
          {
            text: 'For Users',
            link: '/en/users/',
          },
          {
            text: 'For Admins',
            link: '/en/admins/'
          },
          {
            text: 'Source Code',
            link: 'https://git.odit.services/lfk'
          }
        ],
        sidebar: {
          '/en/users/': [
            {
              title: 'User documentation',
              collapsable: false,
              children: [
                ''
              ]
            }
          ],
          '/en/admins/': [
            {
              title: 'Admin documentation',
              collapsable: false,
              children: [
                ''
              ]
            }
          ],
        }
      }
    }
  },
  plugins: [
    '@vuepress/plugin-back-to-top',
    '@vuepress/plugin-medium-zoom',
    'flexsearch'
  ]
}
